@@ -320,11 +320,10 @@ impl Page {
         }
     }
     /// Resize data.
-    fn resize_data(&mut self)
-    {
-      let size = self.size();
-      let data = Data::make_mut(&mut self.data);
-      data.resize(size, 0);
+    fn resize_data(&mut self) {
+        let size = self.size();
+        let data = Data::make_mut(&mut self.data);
+        data.resize(size, 0);
     }
 
     /// Allocate a node.
