@@ -435,7 +435,7 @@ impl Record for Row {
 }
 
 /// Row for inserting into an index.
-struct IndexRow {
+pub struct IndexRow {
     pub tinfo: Rc<ColInfo>,
     pub cols: Rc<Vec<usize>>,
     pub keys: Vec<Value>,
@@ -448,9 +448,11 @@ impl IndexRow {
     fn new(table: &Table, cols: Rc<Vec<usize>>, row: &Row) -> Self {
         let mut keys = Vec::new();
         let mut codes = Vec::new();
-        for c in &*cols {
-            keys.push(row.values[*c].clone());
-            codes.push(row.codes[*c]);
+        if row.codes.len() > 0 {
+            for c in &*cols {
+                keys.push(row.values[*c].clone());
+                codes.push(row.codes[*c]);
+            }
         }
         Self {
             tinfo: table.info.clone(),
